@@ -530,8 +530,8 @@ class Env(object):
     def __call__(self, *a, **kw):
         self._service(*a, **kw).run(self._pty, self._logger)
 
-    def get_subservices(self):
-        for name, subservice in self._service.get_subservices():
+    def get_subservices(self, include_isolations=True):
+        for name, subservice in self._service.get_subservices(include_isolations):
             yield name, self.get_subservice(name)
 
     def get_group(self):
@@ -916,7 +916,10 @@ def get_isolations(service):
     # The parent may not yet have been isolated, and therefore,
     # this may be a list of parents, causing this action to be
     # actually a list of actions.
-    if service.parent and not service.parent._is_isolated and not service_has_host_definitions:
+                # Note that even if this service has its own hosts definitions,
+                # we should isolate the parent. (Because it should still be able
+                # to call self.parent.x.)
+    if service.parent and not service.parent._is_isolated:
         parents = list(get_isolations(service.parent))
     else:
         parents = [ Isolation('', service.parent) ] # service.parent can still be None
@@ -1129,7 +1132,7 @@ class Service(object):
             if not name.startswith('_') and isinstance(member, Action) and not getattr(self, name).is_property:
                 yield name, getattr(self, name)
 
-    def get_subservices(self):
+    def get_subservices(self, include_isolations=True):
         """
         Yield the available nested subservices. Returns tupels of (name, subservice_instance)
         (Except the private ones)
@@ -1143,7 +1146,8 @@ class Service(object):
                     yield name, getattr(self, name)
 
         # Isolations also act as subservices.
-        if self.Meta.isolate_role and not self._is_isolated:
+        if include_isolations and \
+                self.Meta.isolate_role and not self._is_isolated:
             for i in get_isolations(self):
                 yield ':%s' % i.name, i.service
 
